@@ -39,7 +39,7 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET MINIMUM_PERL };
 
-our $VERSION = '0.039_02';
+our $VERSION = '0.040_01';
 
 sub perl_version_introduced {
     my ( $self ) = @_;
@@ -99,6 +99,13 @@ sub __PPIX_TOKEN__post_make {
 
 =cut
 
+    # The extended white space characters came back in Perl 5.21.1
+
+    $self->{perl_version_introduced} =
+	( grep { 127 < ord } split qr{}, $self->content() )
+	? '5.021001'
+	: MINIMUM_PERL;
+
     return;
 }
 
